@@ -16,6 +16,7 @@ from .do import (
     NodeInfoDO,
     NodeMetaDO, 
     NodeUserSettingDO,
+    PodContainerDO,
     PodDO,
     PodOSSOperationInfoDO,
     ResourceOSSSettingDO,
@@ -253,6 +254,15 @@ class K3SController:
         self._check_error(response.status_code, infos)
         return [ServiceDO(**s) for s in infos]
 
+    @exception_class_dec(max_try=1)
+    def get_pod_containers(self, cluster_name:str, namespace_name:str, timeout=30):
+        response=requests.get(
+            f'{self.url}/pod_containers/cluster_name/{cluster_name}/namespace_name/{namespace_name}', 
+            headers=self.header, timeout=timeout)
+        infos = json.loads(response.text)
+        self._check_error(response.status_code, infos)
+        return [PodContainerDO(**s) for s in infos]
+
 
 repo_info = \
 {
